![banner](https://raw.githubusercontent.com/Game-K-Hack/calypso/master/assets/calypso-banner-rounded.jpg)

### CALYPSO

The *Calypso* is an oceanographic vessel equipped and used by the maritime explorer Jacques-Yves Cousteau for his scientific expeditions and documentary film productions.

Named after Calypso, the sea nymph from Greek mythology, the ship and its crew sailed the world’s seas and oceans from November 24, 1951, until January 1996. Through television and books, the *Calypso* became one of the symbols of maritime exploration and global ecology in the second half of the 20th century, in the tradition of its illustrious predecessors such as *La Boussole* and *L’Astrolabe*, the *Beagle*, the *Challenger*, the *Pourquoi Pas?*, and the *Hirondelle*.

## Description

**Calypso** is not only the name of a famous exploration vessel: it’s also a Python library for **web scraping**.  
Unlike general-purpose tools such as HTTrack, which download an entire site before extracting data, Calypso is designed to be **fast and targeted**. It only retrieves the information you need, in an optimized way.  
If the website you want to scrape is supported by the library, **Calypso is the ideal choice**.  

## Supported website

| Logo | Name | Address | Function |
| ---- | ---- | ------- | -------- |
| ![Coomer logo](https://raw.githubusercontent.com/Game-K-Hack/calypso/master/assets/logo/coomer.png) |  Coomer |  [coomer.st](https://coomer.st/) |  `search`, `get_posts`, `download` |
| ![Got any Nudes? logo](https://raw.githubusercontent.com/Game-K-Hack/calypso/master/assets/logo/gotanynudes.png) |  Got any Nudes? |  [gotanynudes.com](https://gotanynudes.com/) |  `search`, `get_posts`, `download` |
| ![Leaked zone logo](https://raw.githubusercontent.com/Game-K-Hack/calypso/master/assets/logo/leakedzone.png) |  Leaked zone |  [leakedzone.com](https://leakedzone.com/) |  `search`, `get_posts`, `download` |
